@@ -1,12 +1,12 @@
 """
-Python wrapper for GitLab API v3
-"""
+gitlab3
+~~~~~~~
 
-__title__ = "gitlab3"
-__version__ = "0.3.1"
-__author__ = "Alex Van't Hof"
-__license__ = "LGPLv3"
-__copyright__ = "Copyright 2013 Alex Van't Hof"
+Python wrapper for GitLab API v3
+
+:copyright: (c) 2013 by Alex Van't Hof.
+:license: LGPLv3, see LICENSE for more details.
+"""
 
 
 import json
@@ -263,7 +263,7 @@ def _add_api(definition, parent):
     cls = type(cls_name, (_GitLabAPI,), cls_attrs)
 
     if _LIST in definition.actions:
-        list_fn = _add_list_fn(cls, definition, parent)
+        _add_list_fn(cls, definition, parent)
         _add_find_fn(cls, name, parent)
     if _GET in definition.actions:
         _add_get_fn(cls, name, parent)
@@ -323,7 +323,7 @@ class _GitLabAPI(object):
         for key, val in data.iteritems():
             if type(val) == dict:
                 self._convert_dates(val)
-            if self._date_fields.get(key):
+            if self._date_fields.get(key) and val:
                 data[key] = self._convert_gitlab_date(val)
 
     def _convert_gitlab_date(self, datetime_str):
